==> mybody_api_client-0.5.18.tar.gz: mybody_api_client-0.5.18/mybody_api_client/routes/admin/products/__init__.py <==
#
# (c) 2024, Yegor Yakubovich, yegoryakubovich.com, personal@yegoryakybovich.com
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#


from mybody_api_client.utils import BaseRoute, RequestTypes


class AdminProductRoute(BaseRoute):
    prefix = '/products'

    async def create(
            self,
            name: str,
            type_: str,
            unit: str,
            fats: float,
            proteins: float,
            carbohydrates: float,
            is_main: bool = False,
            calories: int = None,
            article_id: int = None,
    ):
        return await self.request(
            type_=RequestTypes.POST,
            prefix='/create',
            parameters={
                'name': name,
                'type': type_,
                'is_main': is_main,
                'unit': unit,
                'fats': fats,
                'proteins': proteins,
                'carbohydrates': carbohydrates,
                'calories': calories,
                'article_id': article_id,
            },
            response_key='id',
        )

    async def update(
            self,
            id_: str,
            type_: str,
            unit: str,
            fats: float,
            proteins: float,
            carbohydrates: float,
            is_main: bool,
            calories: int = None,
            article_id: int = None,
    ):
        return await self.request(
            type_=RequestTypes.POST,
            prefix='/update',
            parameters={
                'id': id_,
                'type': type_,
                'is_main': is_main,
                'unit': unit,
                'fats': fats,
                'proteins': proteins,
                'carbohydrates': carbohydrates,
                'calories': calories,
                'article_id': article_id,
            },
        )

    async def delete(self, id_: int):
        return await self.request(
            type_=RequestTypes.POST,
            prefix='/delete',
            parameters={
                'id': id_,
            },
        )

==> mybody_api_client-0.5.21.tar.gz: mybody_api_client-0.5.21/mybody_api_client/routes/admin/products/__init__.py <==
#
# (c) 2024, Yegor Yakubovich, yegoryakubovich.com, personal@yegoryakybovich.com
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#


from mybody_api_client.utils import BaseRoute, RequestTypes


class AdminProductRoute(BaseRoute):
    _prefix = '/products'

    async def create(
            self,
            name: str,
            type_: str,
            unit: str,
            fats: float,
            proteins: float,
            carbohydrates: float,
            is_main: bool = False,
            calories: int = None,
            article_id: int = None,
    ):
        return await self._request(
            type_=RequestTypes.POST,
            prefix='/create',
            parameters={
                'name': name,
                'type': type_,
                'is_main': is_main,
                'unit': unit,
                'fats': fats,
                'proteins': proteins,
                'carbohydrates': carbohydrates,
                'calories': calories,
                'article_id': article_id,
            },
            response_key='id',
        )

    async def update(
            self,
            id_: str,
            type_: str,
            unit: str,
            fats: float,
            proteins: float,
            carbohydrates: float,
            is_main: bool,
            calories: int = None,
            article_id: int = None,
    ):
        return await self._request(
            type_=RequestTypes.POST,
            prefix='/update',
            parameters={
                'id': id_,
                'type': type_,
                'is_main': is_main,
                'unit': unit,
                'fats': fats,
                'proteins': proteins,
                'carbohydrates': carbohydrates,
                'calories': calories,
                'article_id': article_id,
            },
        )

    async def delete(self, id_: int):
        return await self._request(
            type_=RequestTypes.POST,
            prefix='/delete',
            parameters={
                'id': id_,
            },
        )
